@@ -2,7 +2,7 @@
 
 __author__ = """Andres Kepler"""
 __email__ = 'andres.kepler@fleetcomplete.com'
-__version__ = '0.1.6'
+__version__ = '0.1.7'
 
 import datetime
 
@@ -17,8 +17,6 @@ handler = logging.StreamHandler(stream=sys.stdout)
 handler.setFormatter(LogstashFormatterV1())
 logging.basicConfig(handlers=[handler], level=logging.INFO)
 
-logging.info("Start")
-
 def logsstash_logging(args):
     logsstash_host, logsstash_port = args.logstash.split(":")
     logsstash_logger = logging.getLogger()
@@ -74,7 +72,8 @@ class DataOut(object):
 def get_vt10_serial(packet):
     try:
         serial = struct.unpack_from(">16s", bytes(packet), offset=54)[0].decode('utf8')
-    except Exception:
+    except Exception as e:
+        logging.exception(e)
         return None
     if "," in serial:
         serial = serial.split(",")[0]
@@ -87,7 +86,8 @@ def get_ruptela_serial(packet):
     try:
         data = b''.join(struct.unpack_from('>8c', bytes(packet), offset=68))
         serial = str(int.from_bytes(data, byteorder='big'))
-    except Exception:
+    except Exception as e:
+        logging.exception(e)
         return None
     if len(serial) > 15:
         return None
@@ -104,6 +104,7 @@ def get_teltonika_serial(packet):
         fmt = ">{}s".format(str(serial_length))
         serial = struct.unpack_from(fmt, bytes(packet), offset=68)[0].decode('utf8')
     except Exception as e:
+        logging.exception(e)
         return None
     return serial
 
@@ -111,11 +112,14 @@ def get_teltonika_serial(packet):
 def parse_file(args):
     if args.logstash:
         logsstash_logging(args)
+    if args.verbose:
+        logging.getLogger().setLevel(logging.DEBUG)
     serial_collector = []
     packets = rdpcap(args.filename)
     myip = args.filter_dst_ip
     if myip:
         packets = packets.filter(lambda x: x.payload.dst == myip)
+    logging.debug("Start")
     # Let's iterate through every filtered packet
     for packet in packets:
         packet_summ = packet_summary(packet)
@@ -146,5 +150,5 @@ def parse_file(args):
         if serial not in serial_collector:
             serial_collector.append(serial)
             logging.info({"terminal_serial": payload.terminal_serial}, extra=payload.__dict__())
-
+    logging.debug("Stop")
     return 0
